# Changelog

All notable changes to this project will be documented in this file.

## [0.2.0] - 2024-12-16

### 🚜 Refactor

- [**breaking**] Do not use __main__.py (#86)

<!-- generated by git-cliff -->
